aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorjosibake <josibake@protonmail.com>2021-12-10 16:06:28 +0100
committerjosibake <josibake@protonmail.com>2021-12-14 17:50:49 +0100
commitf961c477b56737c546c275e4d86cecfa3f75d48c (patch)
treecda83f07eb010bd890b28648f41c0e72fb97ea0b /src
parent207f1c825c632c54af009516d376d392ea9106fa (diff)
downloadbitcoin-f961c477b56737c546c275e4d86cecfa3f75d48c.tar.xz
refactor: check Good() in tried_collisions test
Rather than try to infer a collision by checking `AddrMan::size`, check whether or not moving to the tried table was successful by checking the output from `AddrMan::Good`
Diffstat (limited to 'src')
-rw-r--r--src/test/addrman_tests.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/test/addrman_tests.cpp b/src/test/addrman_tests.cpp
index 31f30d0379..d74cd5bd4b 100644
--- a/src/test/addrman_tests.cpp
+++ b/src/test/addrman_tests.cpp
@@ -276,24 +276,24 @@ BOOST_AUTO_TEST_CASE(addrman_tried_collisions)
BOOST_CHECK_EQUAL(addrman.size(), num_addrs);
- while (num_addrs < 64) { // Magic number! 250.1.1.1 - 250.1.1.64 do not collide with deterministic key = 1
+ while (num_addrs < 35) { // Magic number! 250.1.1.1 - 250.1.1.35 do not collide in tried with deterministic key = 1
CService addr = ResolveService("250.1.1." + ToString(++num_addrs));
BOOST_CHECK(addrman.Add({CAddress(addr, NODE_NONE)}, source));
- addrman.Good(CAddress(addr, NODE_NONE));
- // Test: No collision in tried table yet.
- BOOST_CHECK_EQUAL(addrman.size(), num_addrs);
+ // Test: Add to tried without collision
+ BOOST_CHECK(addrman.Good(CAddress(addr, NODE_NONE)));
+
}
- // Test: tried table collision!
+ // Test: Unable to add to tried table due to collision!
CService addr1 = ResolveService("250.1.1." + ToString(++num_addrs));
- uint32_t collisions{1};
- BOOST_CHECK(!addrman.Add({CAddress(addr1, NODE_NONE)}, source));
- BOOST_CHECK_EQUAL(addrman.size(), num_addrs - collisions);
+ BOOST_CHECK(addrman.Add({CAddress(addr1, NODE_NONE)}, source));
+ BOOST_CHECK(!addrman.Good(CAddress(addr1, NODE_NONE)));
+ // Test: Add the next address to tried without collision
CService addr2 = ResolveService("250.1.1." + ToString(++num_addrs));
BOOST_CHECK(addrman.Add({CAddress(addr2, NODE_NONE)}, source));
- BOOST_CHECK_EQUAL(addrman.size(), num_addrs - collisions);
+ BOOST_CHECK(addrman.Good(CAddress(addr2, NODE_NONE)));
}
BOOST_AUTO_TEST_CASE(addrman_find)